.. _Api:

API Reference
=============

malaya
------

.. automodule:: malaya
    :members:

malaya.cluster
-----------------

.. automodule:: malaya.cluster
    :members:

malaya.dependency
------------------

.. automodule:: malaya.dependency
    :members:

malaya.emotion
-----------------

.. automodule:: malaya.emotion
    :members:

malaya.entity
---------------

.. automodule:: malaya.entity
    :members:

malaya.generator
-------------------------

.. automodule:: malaya.generator
    :members:

malaya.language_detection
-------------------------

.. automodule:: malaya.language_detection
    :members:

malaya.normalize
-------------------------

.. automodule:: malaya.normalize
    :members:

.. autoclass:: malaya.normalize._SPELL_NORMALIZE()
    :members:

malaya.num2word
-----------------

.. automodule:: malaya.num2word
    :members:

malaya.pos
-----------------

.. automodule:: malaya.pos
    :members:

malaya.preprocessing
----------------------

.. automodule:: malaya.preprocessing
    :members:

malaya.relevancy
------------------

.. automodule:: malaya.relevancy
    :members:

malaya.sentiment
-----------------

.. automodule:: malaya.sentiment
    :members:

malaya.spell
-----------------

.. automodule:: malaya.spell
    :members:

.. autoclass:: malaya.spell._TransformerCorrector()
    :members:

.. autoclass:: malaya.spell._SpellCorrector()
    :members:

.. autoclass:: malaya.spell._SymspellCorrector()
    :members:

malaya.stack
-----------------

.. automodule:: malaya.stack
    :members:

malaya.stem
-----------------

.. automodule:: malaya.stem
    :members:

.. autoclass:: malaya.stem._DEEP_STEMMER()
    :members:

malaya.subjective
-----------------

.. automodule:: malaya.subjective
    :members:

malaya.summarize
---------------------

.. automodule:: malaya.summarize
    :members:

.. autoclass:: malaya.summarize._DEEP_SUMMARIZER()
    :members:

.. autoclass:: malaya.summarize._DEEP_SKIPTHOUGHT()
    :members:

malaya.similarity
-------------------------

.. automodule:: malaya.similarity
    :members:

.. autoclass:: malaya.similarity._VECTORIZER_SIMILARITY()
    :members:

.. autoclass:: malaya.similarity._DOC2VEC_SIMILARITY()
    :members:

malaya.topic_model
-----------------------

.. automodule:: malaya.topic_model
    :members:

.. autoclass:: malaya.topic_model._TOPIC()
    :members:

.. autoclass:: malaya.topic_model._DEEP_TOPIC()
    :members:

malaya.toxic
-------------------------

.. automodule:: malaya.toxic
    :members:

malaya.transformer
-------------------------

.. automodule:: malaya.transformer
    :members:

malaya.wordvector
-------------------------

.. automodule:: malaya.wordvector
    :members:

.. autoclass:: malaya.wordvector._wordvector()
    :members:

malaya._transformer._bert
-----------------------------

.. automodule:: malaya._transformer._bert
    :members:

.. autoclass:: malaya._transformer._bert._Model()
    :members:

malaya._transformer._albert
-----------------------------

.. automodule:: malaya._transformer._albert
    :members:

.. autoclass:: malaya._transformer._albert._Model()
    :members:

malaya._transformer._xlnet
-----------------------------

.. automodule:: malaya._transformer._xlnet
    :members:

.. autoclass:: malaya._transformer._xlnet._Model()
    :members:

malaya._transformer._alxlnet
-----------------------------

.. automodule:: malaya._transformer._alxlnet
    :members:

.. autoclass:: malaya._transformer._alxlnet._Model()
    :members:

malaya._models._tensorflow_model
----------------------------------

.. autoclass:: malaya._models._tensorflow_model._SPARSE_SOFTMAX_MODEL()
    :members:

malaya._models._bert_model
----------------------------------

.. autoclass:: malaya._models._bert_model.BINARY_BERT()
    :members:

.. autoclass:: malaya._models._bert_model.MULTICLASS_BERT()
    :members:

.. autoclass:: malaya._models._bert_model.SIGMOID_BERT()
    :members:

.. autoclass:: malaya._models._bert_model.SIAMESE_BERT()
    :members:

.. autoclass:: malaya._models._bert_model.TAGGING_BERT()
    :members:

.. autoclass:: malaya._models._bert_model.DEPENDENCY_BERT()
    :members:

malaya._models._xlnet_model
----------------------------------

.. autoclass:: malaya._models._xlnet_model.BINARY_XLNET()
    :members:

.. autoclass:: malaya._models._xlnet_model.MULTICLASS_XLNET()
    :members:

.. autoclass:: malaya._models._xlnet_model.SIGMOID_XLNET()
    :members:

.. autoclass:: malaya._models._xlnet_model.SIAMESE_XLNET()
    :members:

.. autoclass:: malaya._models._xlnet_model.TAGGING_XLNET()
    :members:

.. autoclass:: malaya._models._xlnet_model.DEPENDENCY_XLNET()
    :members:
